[![Build Status](https://travis-ci.org/jet/baybars.svg?branch=master)](https://travis-ci.org/jet/baybars)
[![image](https://img.shields.io/pypi/v/baybars.svg)](https://pypi.org/project/baybars/)
[![image](https://img.shields.io/pypi/l/baybars.svg)](https://pypi.org/project/baybars/)
[![image](https://img.shields.io/pypi/pyversions/requests.svg)](https://pypi.org/project/baybars/)

### Baybars
#### Raison D'être: 
  - Common library that are wrappers on other third party libraries to make life easier for engineers.
  - We want better API's to interact various infrastructure, common libraries to be more productive.
  - We also want to share the code so that other people can reuse and make use of it. 

Software is meant to be used and not forgotten.

#### Features
It has great wrappers(beautiful APIs to interact with) for:
  - Nomad(consul, vault)
  - Azure(blob, queue, cosmosdb)
  - Kafka
  - FTP
  - Various image processing utils 
  - Various compression utils
  - Various logging and timestamp utils

#### Upcoming
- [ ] Documentation
- [ ] Tests for each modules and test coverage
- Machine Learning Models(expect some good Tensorflow production ready models)
- Some common preprocessing, feature extraction modules for various data 